/**
 * Application Migration Service API
 * API for the Application Migration service. Use this API to migrate applications from Oracle Cloud Infrastructure - Classic to Oracle Cloud Infrastructure.

 * OpenAPI spec version: 20191031
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { ApplicationMigrationWaiter } from "./applicationmigration-waiter";
export declare enum ApplicationMigrationApiKeys {
}
export declare class ApplicationMigrationClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": ApplicationMigrationWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new ApplicationMigrationWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): ApplicationMigrationWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): ApplicationMigrationWaiter;
    /**
     * Cancels the specified work request
     * @param CancelWorkRequestRequest
     * @return CancelWorkRequestResponse
     * @throws OciError when an error occurs
     */
    cancelWorkRequest(cancelWorkRequestRequest: requests.CancelWorkRequestRequest): Promise<responses.CancelWorkRequestResponse>;
    /**
     * Moves a Migration into a different compartment.
     * @param ChangeMigrationCompartmentRequest
     * @return ChangeMigrationCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeMigrationCompartment(changeMigrationCompartmentRequest: requests.ChangeMigrationCompartmentRequest): Promise<responses.ChangeMigrationCompartmentResponse>;
    /**
     * Moves a Source into a different compartment.
     * @param ChangeSourceCompartmentRequest
     * @return ChangeSourceCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeSourceCompartment(changeSourceCompartmentRequest: requests.ChangeSourceCompartmentRequest): Promise<responses.ChangeSourceCompartmentResponse>;
    /**
     * Creates an application migration in the specified compartment.
     * Specify the compartment using the compartment ID.
     *
     * @param CreateMigrationRequest
     * @return CreateMigrationResponse
     * @throws OciError when an error occurs
     */
    createMigration(createMigrationRequest: requests.CreateMigrationRequest): Promise<responses.CreateMigrationResponse>;
    /**
     * Creates a migration source in the specified compartment.
     * Specify the compartment using the compartment ID.
     *
     * @param CreateSourceRequest
     * @return CreateSourceResponse
     * @throws OciError when an error occurs
     */
    createSource(createSourceRequest: requests.CreateSourceRequest): Promise<responses.CreateSourceResponse>;
    /**
     * Deletes the specified Application object.
     * @param DeleteMigrationRequest
     * @return DeleteMigrationResponse
     * @throws OciError when an error occurs
     */
    deleteMigration(deleteMigrationRequest: requests.DeleteMigrationRequest): Promise<responses.DeleteMigrationResponse>;
    /**
     * Deletes the specified Source object.
     * @param DeleteSourceRequest
     * @return DeleteSourceResponse
     * @throws OciError when an error occurs
     */
    deleteSource(deleteSourceRequest: requests.DeleteSourceRequest): Promise<responses.DeleteSourceResponse>;
    /**
     * Gets an application migration using the ID.
     * @param GetMigrationRequest
     * @return GetMigrationResponse
     * @throws OciError when an error occurs
     */
    getMigration(getMigrationRequest: requests.GetMigrationRequest): Promise<responses.GetMigrationResponse>;
    /**
     * Gets a migration source using the source ID.
     * @param GetSourceRequest
     * @return GetSourceResponse
     * @throws OciError when an error occurs
     */
    getSource(getSourceRequest: requests.GetSourceRequest): Promise<responses.GetSourceResponse>;
    /**
     * Gets the details of a work request.
     * @param GetWorkRequestRequest
     * @return GetWorkRequestResponse
     * @throws OciError when an error occurs
     */
    getWorkRequest(getWorkRequestRequest: requests.GetWorkRequestRequest): Promise<responses.GetWorkRequestResponse>;
    /**
     * Returns a list of migrations in a given compartment.
     *
     * @param ListMigrationsRequest
     * @return ListMigrationsResponse
     * @throws OciError when an error occurs
     */
    listMigrations(listMigrationsRequest: requests.ListMigrationsRequest): Promise<responses.ListMigrationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.MigrationSummary objects
     * contained in responses from the listMigrations operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMigrations(request: requests.ListMigrationsRequest): AsyncIterableIterator<models.MigrationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listMigrations operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllMigrationsResponses(request: requests.ListMigrationsRequest): AsyncIterableIterator<responses.ListMigrationsResponse>;
    /**
     * Returns a list of applications running in the source environment. This list is generated dynamically by interrogating the source and changes as applications are started or stopped in that environment.
     *
     * @param ListSourceApplicationsRequest
     * @return ListSourceApplicationsResponse
     * @throws OciError when an error occurs
     */
    listSourceApplications(listSourceApplicationsRequest: requests.ListSourceApplicationsRequest): Promise<responses.ListSourceApplicationsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SourceApplicationSummary objects
     * contained in responses from the listSourceApplications operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSourceApplications(request: requests.ListSourceApplicationsRequest): AsyncIterableIterator<models.SourceApplicationSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSourceApplications operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSourceApplicationsResponses(request: requests.ListSourceApplicationsRequest): AsyncIterableIterator<responses.ListSourceApplicationsResponse>;
    /**
     * Returns a list of migration sources in a specified compartment.
     *
     * @param ListSourcesRequest
     * @return ListSourcesResponse
     * @throws OciError when an error occurs
     */
    listSources(listSourcesRequest: requests.ListSourcesRequest): Promise<responses.ListSourcesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SourceSummary objects
     * contained in responses from the listSources operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSources(request: requests.ListSourcesRequest): AsyncIterableIterator<models.SourceSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSources operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSourcesResponses(request: requests.ListSourcesRequest): AsyncIterableIterator<responses.ListSourcesResponse>;
    /**
     * Gets the errors for a work request.
     *
     * @param ListWorkRequestErrorsRequest
     * @return ListWorkRequestErrorsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestErrors(listWorkRequestErrorsRequest: requests.ListWorkRequestErrorsRequest): Promise<responses.ListWorkRequestErrorsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestError objects
     * contained in responses from the listWorkRequestErrors operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrors(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<models.WorkRequestError>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestErrors operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestErrorsResponses(request: requests.ListWorkRequestErrorsRequest): AsyncIterableIterator<responses.ListWorkRequestErrorsResponse>;
    /**
     * Gets the logs for a work request.
     *
     * @param ListWorkRequestLogsRequest
     * @return ListWorkRequestLogsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequestLogs(listWorkRequestLogsRequest: requests.ListWorkRequestLogsRequest): Promise<responses.ListWorkRequestLogsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestLogEntry objects
     * contained in responses from the listWorkRequestLogs operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogs(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<models.WorkRequestLogEntry>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequestLogs operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestLogsResponses(request: requests.ListWorkRequestLogsRequest): AsyncIterableIterator<responses.ListWorkRequestLogsResponse>;
    /**
     * Lists the work requests in a compartment or for a specified resource.
     *
     * @param ListWorkRequestsRequest
     * @return ListWorkRequestsResponse
     * @throws OciError when an error occurs
     */
    listWorkRequests(listWorkRequestsRequest: requests.ListWorkRequestsRequest): Promise<responses.ListWorkRequestsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.WorkRequestSummary objects
     * contained in responses from the listWorkRequests operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequests(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<models.WorkRequestSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listWorkRequests operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllWorkRequestsResponses(request: requests.ListWorkRequestsRequest): AsyncIterableIterator<responses.ListWorkRequestsResponse>;
    /**
     * Validates target configuration and migrates a PaaS application running in a Source environment into the customers Oracle Cloud Infrastructure tenancy. This an optional action and only required if automatic start of migration was not selected when creating the migration.
     *
     * @param MigrateApplicationRequest
     * @return MigrateApplicationResponse
     * @throws OciError when an error occurs
     */
    migrateApplication(migrateApplicationRequest: requests.MigrateApplicationRequest): Promise<responses.MigrateApplicationResponse>;
    /**
     * Update the configuration for an application migration.
     * @param UpdateMigrationRequest
     * @return UpdateMigrationResponse
     * @throws OciError when an error occurs
     */
    updateMigration(updateMigrationRequest: requests.UpdateMigrationRequest): Promise<responses.UpdateMigrationResponse>;
    /**
     * Update source details.
     * @param UpdateSourceRequest
     * @return UpdateSourceResponse
     * @throws OciError when an error occurs
     */
    updateSource(updateSourceRequest: requests.UpdateSourceRequest): Promise<responses.UpdateSourceResponse>;
}
