/**
 * DNS API
 * API for the DNS service. Use this API to manage DNS zones, records, and other DNS resources.
For more information, see [Overview of the DNS Service](/iaas/Content/DNS/Concepts/dnszonemanagement.htm).

 * OpenAPI spec version: 20180115
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as models from "./model";
import * as responses from "./response";
import { DnsWaiter } from "./dns-waiter";
export declare enum DnsApiKeys {
}
export declare class DnsClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_waiters": DnsWaiter;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Creates a new DnsWaiter for resources for this service.
     *
     * @param config The waiter configuration for termination and delay strategy
     * @return The service waiters.
     */
    createWaiters(config?: common.WaiterConfiguration): DnsWaiter;
    /**
     * Gets the waiters available for resources for this service.
     *
     * @return The service waiters.
     */
    getWaiters(): DnsWaiter;
    /**
     * Moves a steering policy into a different compartment.
     * @param ChangeSteeringPolicyCompartmentRequest
     * @return ChangeSteeringPolicyCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeSteeringPolicyCompartment(changeSteeringPolicyCompartmentRequest: requests.ChangeSteeringPolicyCompartmentRequest): Promise<responses.ChangeSteeringPolicyCompartmentResponse>;
    /**
     * Moves a TSIG key into a different compartment.
     * @param ChangeTsigKeyCompartmentRequest
     * @return ChangeTsigKeyCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeTsigKeyCompartment(changeTsigKeyCompartmentRequest: requests.ChangeTsigKeyCompartmentRequest): Promise<responses.ChangeTsigKeyCompartmentResponse>;
    /**
     * Moves a zone into a different compartment.
     * **Note:** All SteeringPolicyAttachment objects associated with this zone will also be moved into the provided compartment.
     * @param ChangeZoneCompartmentRequest
     * @return ChangeZoneCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeZoneCompartment(changeZoneCompartmentRequest: requests.ChangeZoneCompartmentRequest): Promise<responses.ChangeZoneCompartmentResponse>;
    /**
     * Creates a new steering policy in the specified compartment. For more information on
     * creating policies with templates, see [Traffic Management API Guide](https://docs.cloud.oracle.com/iaas/Content/TrafficManagement/Concepts/trafficmanagementapi.htm).
     *
     * @param CreateSteeringPolicyRequest
     * @return CreateSteeringPolicyResponse
     * @throws OciError when an error occurs
     */
    createSteeringPolicy(createSteeringPolicyRequest: requests.CreateSteeringPolicyRequest): Promise<responses.CreateSteeringPolicyResponse>;
    /**
       * Creates a new attachment between a steering policy and a domain, giving the
  * policy permission to answer queries for the specified domain. A steering policy must
  * be attached to a domain for the policy to answer DNS queries for that domain.
  * <p>
  For the purposes of access control, the attachment is automatically placed
  * into the same compartment as the domain's zone.
  *
       * @param CreateSteeringPolicyAttachmentRequest
       * @return CreateSteeringPolicyAttachmentResponse
       * @throws OciError when an error occurs
       */
    createSteeringPolicyAttachment(createSteeringPolicyAttachmentRequest: requests.CreateSteeringPolicyAttachmentRequest): Promise<responses.CreateSteeringPolicyAttachmentResponse>;
    /**
     * Creates a new TSIG key in the specified compartment. There is no
     * `opc-retry-token` header since TSIG key names must be globally unique.
     *
     * @param CreateTsigKeyRequest
     * @return CreateTsigKeyResponse
     * @throws OciError when an error occurs
     */
    createTsigKey(createTsigKeyRequest: requests.CreateTsigKeyRequest): Promise<responses.CreateTsigKeyResponse>;
    /**
     * Creates a new zone in the specified compartment. The `compartmentId`
     * query parameter is required if the `Content-Type` header for the
     * request is `text/dns`.
     *
     * @param CreateZoneRequest
     * @return CreateZoneResponse
     * @throws OciError when an error occurs
     */
    createZone(createZoneRequest: requests.CreateZoneRequest): Promise<responses.CreateZoneResponse>;
    /**
     * Deletes all records at the specified zone and domain.
     * @param DeleteDomainRecordsRequest
     * @return DeleteDomainRecordsResponse
     * @throws OciError when an error occurs
     */
    deleteDomainRecords(deleteDomainRecordsRequest: requests.DeleteDomainRecordsRequest): Promise<responses.DeleteDomainRecordsResponse>;
    /**
     * Deletes all records in the specified RRSet.
     *
     * @param DeleteRRSetRequest
     * @return DeleteRRSetResponse
     * @throws OciError when an error occurs
     */
    deleteRRSet(deleteRRSetRequest: requests.DeleteRRSetRequest): Promise<responses.DeleteRRSetResponse>;
    /**
     * Deletes the specified steering policy.
     * A `204` response indicates that the delete has been successful.
     * Deletion will fail if the policy is attached to any zones. To detach a
     * policy from a zone, see `DeleteSteeringPolicyAttachment`.
     *
     * @param DeleteSteeringPolicyRequest
     * @return DeleteSteeringPolicyResponse
     * @throws OciError when an error occurs
     */
    deleteSteeringPolicy(deleteSteeringPolicyRequest: requests.DeleteSteeringPolicyRequest): Promise<responses.DeleteSteeringPolicyResponse>;
    /**
     * Deletes the specified steering policy attachment.
     * A `204` response indicates that the delete has been successful.
     *
     * @param DeleteSteeringPolicyAttachmentRequest
     * @return DeleteSteeringPolicyAttachmentResponse
     * @throws OciError when an error occurs
     */
    deleteSteeringPolicyAttachment(deleteSteeringPolicyAttachmentRequest: requests.DeleteSteeringPolicyAttachmentRequest): Promise<responses.DeleteSteeringPolicyAttachmentResponse>;
    /**
     * Deletes the specified TSIG key.
     *
     * @param DeleteTsigKeyRequest
     * @return DeleteTsigKeyResponse
     * @throws OciError when an error occurs
     */
    deleteTsigKey(deleteTsigKeyRequest: requests.DeleteTsigKeyRequest): Promise<responses.DeleteTsigKeyResponse>;
    /**
     * Deletes the specified zone and all its steering policy attachments.
     * A `204` response indicates that zone has been successfully deleted.
     *
     * @param DeleteZoneRequest
     * @return DeleteZoneResponse
     * @throws OciError when an error occurs
     */
    deleteZone(deleteZoneRequest: requests.DeleteZoneRequest): Promise<responses.DeleteZoneResponse>;
    /**
     * Gets a list of all records at the specified zone and domain.
     * The results are sorted by `rtype` in alphabetical order by default. You
     * can optionally filter and/or sort the results using the listed parameters.
     *
     * @param GetDomainRecordsRequest
     * @return GetDomainRecordsResponse
     * @throws OciError when an error occurs
     */
    getDomainRecords(getDomainRecordsRequest: requests.GetDomainRecordsRequest): Promise<responses.GetDomainRecordsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Record objects
     * contained in responses from the getDomainRecords operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllDomainRecords(request: requests.GetDomainRecordsRequest): AsyncIterableIterator<models.Record>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the getDomainRecords operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllDomainRecordsResponses(request: requests.GetDomainRecordsRequest): AsyncIterableIterator<responses.GetDomainRecordsResponse>;
    /**
     * Gets a list of all records in the specified RRSet. The results are
     * sorted by `recordHash` by default.
     *
     * @param GetRRSetRequest
     * @return GetRRSetResponse
     * @throws OciError when an error occurs
     */
    getRRSet(getRRSetRequest: requests.GetRRSetRequest): Promise<responses.GetRRSetResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Record objects
     * contained in responses from the getRRSet operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllRRSet(request: requests.GetRRSetRequest): AsyncIterableIterator<models.Record>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the getRRSet operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllRRSetResponses(request: requests.GetRRSetRequest): AsyncIterableIterator<responses.GetRRSetResponse>;
    /**
     * Gets information about the specified steering policy.
     *
     * @param GetSteeringPolicyRequest
     * @return GetSteeringPolicyResponse
     * @throws OciError when an error occurs
     */
    getSteeringPolicy(getSteeringPolicyRequest: requests.GetSteeringPolicyRequest): Promise<responses.GetSteeringPolicyResponse>;
    /**
     * Gets information about the specified steering policy attachment.
     *
     * @param GetSteeringPolicyAttachmentRequest
     * @return GetSteeringPolicyAttachmentResponse
     * @throws OciError when an error occurs
     */
    getSteeringPolicyAttachment(getSteeringPolicyAttachmentRequest: requests.GetSteeringPolicyAttachmentRequest): Promise<responses.GetSteeringPolicyAttachmentResponse>;
    /**
     * Gets information about the specified TSIG key.
     *
     * @param GetTsigKeyRequest
     * @return GetTsigKeyResponse
     * @throws OciError when an error occurs
     */
    getTsigKey(getTsigKeyRequest: requests.GetTsigKeyRequest): Promise<responses.GetTsigKeyResponse>;
    /**
     * Gets information about the specified zone, including its creation date,
     * zone type, and serial.
     *
     * @param GetZoneRequest
     * @return GetZoneResponse
     * @throws OciError when an error occurs
     */
    getZone(getZoneRequest: requests.GetZoneRequest): Promise<responses.GetZoneResponse>;
    /**
     * Gets all records in the specified zone. The results are
     * sorted by `domain` in alphabetical order by default. For more
     * information about records, see [Resource Record (RR) TYPEs](https://www.iana.org/assignments/dns-parameters/dns-parameters.xhtml#dns-parameters-4).
     *
     * @param GetZoneRecordsRequest
     * @return GetZoneRecordsResponse
     * @throws OciError when an error occurs
     */
    getZoneRecords(getZoneRecordsRequest: requests.GetZoneRecordsRequest): Promise<responses.GetZoneRecordsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.Record objects
     * contained in responses from the getZoneRecords operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllZoneRecords(request: requests.GetZoneRecordsRequest): AsyncIterableIterator<models.Record>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the getZoneRecords operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    getAllZoneRecordsResponses(request: requests.GetZoneRecordsRequest): AsyncIterableIterator<responses.GetZoneRecordsResponse>;
    /**
     * Gets a list of all steering policies in the specified compartment.
     *
     * @param ListSteeringPoliciesRequest
     * @return ListSteeringPoliciesResponse
     * @throws OciError when an error occurs
     */
    listSteeringPolicies(listSteeringPoliciesRequest: requests.ListSteeringPoliciesRequest): Promise<responses.ListSteeringPoliciesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SteeringPolicySummary objects
     * contained in responses from the listSteeringPolicies operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSteeringPolicies(request: requests.ListSteeringPoliciesRequest): AsyncIterableIterator<models.SteeringPolicySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSteeringPolicies operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSteeringPoliciesResponses(request: requests.ListSteeringPoliciesRequest): AsyncIterableIterator<responses.ListSteeringPoliciesResponse>;
    /**
     * Lists the steering policy attachments in the specified compartment.
     *
     * @param ListSteeringPolicyAttachmentsRequest
     * @return ListSteeringPolicyAttachmentsResponse
     * @throws OciError when an error occurs
     */
    listSteeringPolicyAttachments(listSteeringPolicyAttachmentsRequest: requests.ListSteeringPolicyAttachmentsRequest): Promise<responses.ListSteeringPolicyAttachmentsResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.SteeringPolicyAttachmentSummary objects
     * contained in responses from the listSteeringPolicyAttachments operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSteeringPolicyAttachments(request: requests.ListSteeringPolicyAttachmentsRequest): AsyncIterableIterator<models.SteeringPolicyAttachmentSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listSteeringPolicyAttachments operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllSteeringPolicyAttachmentsResponses(request: requests.ListSteeringPolicyAttachmentsRequest): AsyncIterableIterator<responses.ListSteeringPolicyAttachmentsResponse>;
    /**
     * Gets a list of all TSIG keys in the specified compartment.
     *
     * @param ListTsigKeysRequest
     * @return ListTsigKeysResponse
     * @throws OciError when an error occurs
     */
    listTsigKeys(listTsigKeysRequest: requests.ListTsigKeysRequest): Promise<responses.ListTsigKeysResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.TsigKeySummary objects
     * contained in responses from the listTsigKeys operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllTsigKeys(request: requests.ListTsigKeysRequest): AsyncIterableIterator<models.TsigKeySummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listTsigKeys operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllTsigKeysResponses(request: requests.ListTsigKeysRequest): AsyncIterableIterator<responses.ListTsigKeysResponse>;
    /**
     * Gets a list of all zones in the specified compartment. The collection
     * can be filtered by name, time created, and zone type.
     *
     * @param ListZonesRequest
     * @return ListZonesResponse
     * @throws OciError when an error occurs
     */
    listZones(listZonesRequest: requests.ListZonesRequest): Promise<responses.ListZonesResponse>;
    /**
     * Creates a new async iterator which will iterate over the models.ZoneSummary objects
     * contained in responses from the listZones operation. This iterator will fetch more data from the
     * server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllZones(request: requests.ListZonesRequest): AsyncIterableIterator<models.ZoneSummary>;
    /**
     * Creates a new async iterator which will iterate over the responses received from the listZones operation. This iterator
     * will fetch more data from the server as needed.
     *
     * @param request a request which can be sent to the service operation
     */
    listAllZonesResponses(request: requests.ListZonesRequest): AsyncIterableIterator<responses.ListZonesResponse>;
    /**
     * Updates records in the specified zone at a domain. You can update
     * one record or all records for the specified zone depending on the changes
     * provided in the request body. You can also add or remove records using this
     * function.
     *
     * @param PatchDomainRecordsRequest
     * @return PatchDomainRecordsResponse
     * @throws OciError when an error occurs
     */
    patchDomainRecords(patchDomainRecordsRequest: requests.PatchDomainRecordsRequest): Promise<responses.PatchDomainRecordsResponse>;
    /**
     * Updates records in the specified RRSet.
     * @param PatchRRSetRequest
     * @return PatchRRSetResponse
     * @throws OciError when an error occurs
     */
    patchRRSet(patchRRSetRequest: requests.PatchRRSetRequest): Promise<responses.PatchRRSetResponse>;
    /**
     * Updates a collection of records in the specified zone. You can update
     * one record or all records for the specified zone depending on the
     * changes provided in the request body. You can also add or remove records
     * using this function.
     *
     * @param PatchZoneRecordsRequest
     * @return PatchZoneRecordsResponse
     * @throws OciError when an error occurs
     */
    patchZoneRecords(patchZoneRecordsRequest: requests.PatchZoneRecordsRequest): Promise<responses.PatchZoneRecordsResponse>;
    /**
     * Replaces records in the specified zone at a domain with the records
     * specified in the request body. If a specified record does not exist,
     * it will be created. If the record exists, then it will be updated to
     * represent the record in the body of the request. If a record in the zone
     * does not exist in the request body, the record will be removed from the
     * zone.
     *
     * @param UpdateDomainRecordsRequest
     * @return UpdateDomainRecordsResponse
     * @throws OciError when an error occurs
     */
    updateDomainRecords(updateDomainRecordsRequest: requests.UpdateDomainRecordsRequest): Promise<responses.UpdateDomainRecordsResponse>;
    /**
     * Replaces records in the specified RRSet.
     * @param UpdateRRSetRequest
     * @return UpdateRRSetResponse
     * @throws OciError when an error occurs
     */
    updateRRSet(updateRRSetRequest: requests.UpdateRRSetRequest): Promise<responses.UpdateRRSetResponse>;
    /**
     * Updates the configuration of the specified steering policy.
     *
     * @param UpdateSteeringPolicyRequest
     * @return UpdateSteeringPolicyResponse
     * @throws OciError when an error occurs
     */
    updateSteeringPolicy(updateSteeringPolicyRequest: requests.UpdateSteeringPolicyRequest): Promise<responses.UpdateSteeringPolicyResponse>;
    /**
     * Updates the specified steering policy attachment with your new information.
     *
     * @param UpdateSteeringPolicyAttachmentRequest
     * @return UpdateSteeringPolicyAttachmentResponse
     * @throws OciError when an error occurs
     */
    updateSteeringPolicyAttachment(updateSteeringPolicyAttachmentRequest: requests.UpdateSteeringPolicyAttachmentRequest): Promise<responses.UpdateSteeringPolicyAttachmentResponse>;
    /**
     * Updates the specified TSIG key.
     *
     * @param UpdateTsigKeyRequest
     * @return UpdateTsigKeyResponse
     * @throws OciError when an error occurs
     */
    updateTsigKey(updateTsigKeyRequest: requests.UpdateTsigKeyRequest): Promise<responses.UpdateTsigKeyResponse>;
    /**
     * Updates the specified secondary zone with your new external master
     * server information. For more information about secondary zone, see
     * [Manage DNS Service Zone](https://docs.cloud.oracle.com/iaas/Content/DNS/Tasks/managingdnszones.htm).
     *
     * @param UpdateZoneRequest
     * @return UpdateZoneResponse
     * @throws OciError when an error occurs
     */
    updateZone(updateZoneRequest: requests.UpdateZoneRequest): Promise<responses.UpdateZoneResponse>;
    /**
     * Replaces records in the specified zone with the records specified in the
     * request body. If a specified record does not exist, it will be created.
     * If the record exists, then it will be updated to represent the record in
     * the body of the request. If a record in the zone does not exist in the
     * request body, the record will be removed from the zone.
     *
     * @param UpdateZoneRecordsRequest
     * @return UpdateZoneRecordsResponse
     * @throws OciError when an error occurs
     */
    updateZoneRecords(updateZoneRecordsRequest: requests.UpdateZoneRecordsRequest): Promise<responses.UpdateZoneRecordsResponse>;
}
