/**
 * ManagementDashboard API
 * Management Dashboard micro-service provides a set of CRUD, import, export, and compartment related APIs (such as change compartment)   to support dashboard and saved search metadata preservation.  These APIs are mainly for client UIs, for various UI activities such as get list of all saved searches in a compartment, create a dashboard, open a saved search, etc.  Use export to retrieve  dashboards and their saved searches, then edit the Json if necessary (for example change compartmentIds), then import the result to  destination dashboard service.
APIs validate all required properties to ensure properties are present and have correct type and values.
    

 * OpenAPI spec version: 20200901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import common = require("oci-common");
import * as requests from "./request";
import * as responses from "./response";
export declare enum DashxApisApiKeys {
}
export declare class DashxApisClient {
    protected static serviceEndpointTemplate: string;
    protected "_endpoint": string;
    protected "_defaultHeaders": any;
    protected "_clientConfiguration": common.ClientConfiguration;
    protected _circuitBreaker: null;
    protected _httpClient: common.HttpClient;
    constructor(params: common.AuthParams, clientConfiguration?: common.ClientConfiguration);
    /**
     * Get the endpoint that is being used to call (ex, https://www.example.com).
     */
    /**
    * Sets the endpoint to call (ex, https://www.example.com).
    * @param endpoint The endpoint of the service.
    */
    endpoint: string;
    readonly logger: import("oci-common/lib/log").Logger;
    /**
     * Sets the region to call (ex, Region.US_PHOENIX_1).
     * Note, this will call {@link #endpoint(String) endpoint} after resolving the endpoint.
     * @param region The region of the service.
     */
    region: common.Region;
    /**
     * Sets the regionId to call (ex, 'us-phoenix-1').
     *
     * Note, this will first try to map the region ID to a known Region and call {@link #region(Region) region}.
     * If no known Region could be determined, it will create an endpoint assuming its in default Realm OC1
     * and then call {@link #endpoint(String) endpoint}.
     * @param regionId The public region ID.
     */
    regionId: string;
    /**
     * Move the dashboard from existing compartment to a new compartment.
     *
     * @param ChangeManagementDashboardsCompartmentRequest
     * @return ChangeManagementDashboardsCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeManagementDashboardsCompartment(changeManagementDashboardsCompartmentRequest: requests.ChangeManagementDashboardsCompartmentRequest): Promise<responses.ChangeManagementDashboardsCompartmentResponse>;
    /**
     * Move the saved search from existing compartment to a new compartment.
     *
     * @param ChangeManagementSavedSearchesCompartmentRequest
     * @return ChangeManagementSavedSearchesCompartmentResponse
     * @throws OciError when an error occurs
     */
    changeManagementSavedSearchesCompartment(changeManagementSavedSearchesCompartmentRequest: requests.ChangeManagementSavedSearchesCompartmentRequest): Promise<responses.ChangeManagementSavedSearchesCompartmentResponse>;
    /**
     * Creates a new dashboard.  Limit for number of saved searches in a dashboard is 20.
     *
     * @param CreateManagementDashboardRequest
     * @return CreateManagementDashboardResponse
     * @throws OciError when an error occurs
     */
    createManagementDashboard(createManagementDashboardRequest: requests.CreateManagementDashboardRequest): Promise<responses.CreateManagementDashboardResponse>;
    /**
     * Creates a new saved search.
     *
     * @param CreateManagementSavedSearchRequest
     * @return CreateManagementSavedSearchResponse
     * @throws OciError when an error occurs
     */
    createManagementSavedSearch(createManagementSavedSearchRequest: requests.CreateManagementSavedSearchRequest): Promise<responses.CreateManagementSavedSearchResponse>;
    /**
     * Deletes a Dashboard by id.
     * @param DeleteManagementDashboardRequest
     * @return DeleteManagementDashboardResponse
     * @throws OciError when an error occurs
     */
    deleteManagementDashboard(deleteManagementDashboardRequest: requests.DeleteManagementDashboardRequest): Promise<responses.DeleteManagementDashboardResponse>;
    /**
     * Deletes a saved search by Id
     * @param DeleteManagementSavedSearchRequest
     * @return DeleteManagementSavedSearchResponse
     * @throws OciError when an error occurs
     */
    deleteManagementSavedSearch(deleteManagementSavedSearchRequest: requests.DeleteManagementSavedSearchRequest): Promise<responses.DeleteManagementSavedSearchResponse>;
    /**
     * Exports an array of dashboards and their saved searches.
     * @param ExportDashboardRequest
     * @return ExportDashboardResponse
     * @throws OciError when an error occurs
     */
    exportDashboard(exportDashboardRequest: requests.ExportDashboardRequest): Promise<responses.ExportDashboardResponse>;
    /**
     * Get a Dashboard and its saved searches by id.  Deleted or unauthorized saved searches are marked by tile's state property.
     * @param GetManagementDashboardRequest
     * @return GetManagementDashboardResponse
     * @throws OciError when an error occurs
     */
    getManagementDashboard(getManagementDashboardRequest: requests.GetManagementDashboardRequest): Promise<responses.GetManagementDashboardResponse>;
    /**
     * Get a saved search by Id.
     * @param GetManagementSavedSearchRequest
     * @return GetManagementSavedSearchResponse
     * @throws OciError when an error occurs
     */
    getManagementSavedSearch(getManagementSavedSearchRequest: requests.GetManagementSavedSearchRequest): Promise<responses.GetManagementSavedSearchResponse>;
    /**
     * Import an array of dashboards and their saved searches.
     *
     * @param ImportDashboardRequest
     * @return ImportDashboardResponse
     * @throws OciError when an error occurs
     */
    importDashboard(importDashboardRequest: requests.ImportDashboardRequest): Promise<responses.ImportDashboardResponse>;
    /**
     * Gets list of dashboards and their saved searches for compartment with pagination.  Returned properties are a summary.
     * @param ListManagementDashboardsRequest
     * @return ListManagementDashboardsResponse
     * @throws OciError when an error occurs
     */
    listManagementDashboards(listManagementDashboardsRequest: requests.ListManagementDashboardsRequest): Promise<responses.ListManagementDashboardsResponse>;
    /**
     * Gets list of saved searches with pagination.  Returned properties are a summary.
     * @param ListManagementSavedSearchesRequest
     * @return ListManagementSavedSearchesResponse
     * @throws OciError when an error occurs
     */
    listManagementSavedSearches(listManagementSavedSearchesRequest: requests.ListManagementSavedSearchesRequest): Promise<responses.ListManagementSavedSearchesResponse>;
    /**
     * Updates an existing dashboard identified by id path parameter.  Limit for number of saved searches in a dashboard is 20.
     *
     * @param UpdateManagementDashboardRequest
     * @return UpdateManagementDashboardResponse
     * @throws OciError when an error occurs
     */
    updateManagementDashboard(updateManagementDashboardRequest: requests.UpdateManagementDashboardRequest): Promise<responses.UpdateManagementDashboardResponse>;
    /**
     * Update an existing saved search.  Id cannot be updated.
     *
     * @param UpdateManagementSavedSearchRequest
     * @return UpdateManagementSavedSearchResponse
     * @throws OciError when an error occurs
     */
    updateManagementSavedSearch(updateManagementSavedSearchRequest: requests.UpdateManagementSavedSearchRequest): Promise<responses.UpdateManagementSavedSearchResponse>;
}
