/**
 * ManagementDashboard API
 * Management Dashboard micro-service provides a set of CRUD, import, export, and compartment related APIs (such as change compartment)   to support dashboard and saved search metadata preservation.  These APIs are mainly for client UIs, for various UI activities such as get list of all saved searches in a compartment, create a dashboard, open a saved search, etc.  Use export to retrieve  dashboards and their saved searches, then edit the Json if necessary (for example change compartmentIds), then import the result to  destination dashboard service.
APIs validate all required properties to ensure properties are present and have correct type and values.
    

 * OpenAPI spec version: 20200901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Properties for a dashboard.  Id is not required if not Out Of the Box dashboard.
 */
export interface CreateManagementDashboardDetails {
    /**
     * Dashboard Id. Must be providied if OOB, otherwise must not be provided.
     */
    "dashboardId"?: string;
    /**
     * Provider Id.
     */
    "providerId": string;
    /**
     * Provider name.
     */
    "providerName": string;
    /**
     * Provider version.
     */
    "providerVersion": string;
    /**
     * Dashboard tiles array.
     */
    "tiles": Array<model.ManagementDashboardTileDetails>;
    /**
     * Display name for dashboard.
     */
    "displayName": string;
    /**
     * Dashboard's description.
     */
    "description": string;
    /**
     * The ocid of the compartment that owns the dashboard.
     */
    "compartmentId": string;
    /**
     * String boolean (\"true\" or \"false\").  OOB (Out of the Box) dashboards are only provided by Oracle.  They cannot be modified by non-Oracle.
     */
    "isOobDashboard": boolean;
    /**
     * String boolean (\"true\" or \"false\").  When false, dashboard is not shown in dashboard home.
     */
    "isShowInHome": boolean;
    /**
     * Version of the metadata.
     */
    "metadataVersion": string;
    /**
     * String boolean (\"true\" or \"false\").  Whether to show the dashboard description.
     */
    "isShowDescription": boolean;
    /**
     * screen image.
     */
    "screenImage": string;
    /**
     * Json for internationalization.
     */
    "nls": any;
    /**
     * Json to contain options for UI.
     */
    "uiConfig": any;
    /**
     * Array of Json to contain options for source of data.
     */
    "dataConfig": Array<any>;
    /**
     * NORMAL means single dashboard, or SET means dashboard set.
     */
    "type": string;
    /**
     * String boolean (\"true\" or \"false\").
     */
    "isFavorite": boolean;
    /**
     * Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
     * Example: `{\"bar-key\": \"value\"}`
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace CreateManagementDashboardDetails {
    function getJsonObj(obj: CreateManagementDashboardDetails): object;
}
